

-- GovWay Configurazione

-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_users_ricerche_1;
-- DROP INDEX index_users_servizi_1;
-- DROP INDEX index_users_soggetti_1;
DROP TABLE users_ricerche_init_seq;
DROP TABLE users_ricerche;
DROP TABLE users_servizi_init_seq;
DROP TABLE users_servizi;
DROP TABLE users_soggetti_init_seq;
DROP TABLE users_soggetti;
DROP TABLE users_password_init_seq;
DROP TABLE users_password;
DROP TABLE users_stati_init_seq;
DROP TABLE users_stati;
DROP TABLE users_init_seq;
DROP TABLE users;
DROP SEQUENCE seq_users_ricerche;
DROP SEQUENCE seq_users_servizi;
DROP SEQUENCE seq_users_soggetti;
DROP SEQUENCE seq_users_password;
DROP SEQUENCE seq_users_stati;
DROP SEQUENCE seq_users;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TABLE audit_appender_prop_init_seq;
DROP TABLE audit_appender_prop;
DROP TABLE audit_appender_init_seq;
DROP TABLE audit_appender;
DROP TABLE audit_filters_init_seq;
DROP TABLE audit_filters;
DROP TABLE audit_conf_init_seq;
DROP TABLE audit_conf;
DROP SEQUENCE seq_audit_appender_prop;
DROP SEQUENCE seq_audit_appender;
DROP SEQUENCE seq_audit_filters;
DROP SEQUENCE seq_audit_conf;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_audit_binaries_1;
-- DROP INDEX audit_filter;
-- DROP INDEX audit_object_old_id;
-- DROP INDEX audit_object_id;
-- DROP INDEX audit_filter_time;
DROP TABLE audit_binaries_init_seq;
DROP TABLE audit_binaries;
DROP TABLE audit_operations_init_seq;
DROP TABLE audit_operations;
DROP SEQUENCE seq_audit_binaries;
DROP SEQUENCE seq_audit_operations;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_mapping_erogazione_pa_2;
-- DROP INDEX index_mapping_erogazione_pa_1;
-- DROP INDEX index_mapping_fruizione_pd_2;
-- DROP INDEX index_mapping_fruizione_pd_1;
DROP TABLE mapping_erogazione_pa_init_seq;
DROP TABLE mapping_erogazione_pa;
DROP TABLE mapping_fruizione_pd_init_seq;
DROP TABLE mapping_fruizione_pd;
DROP SEQUENCE seq_mapping_erogazione_pa;
DROP SEQUENCE seq_mapping_fruizione_pd;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_pa_token_ruoli_1;
-- DROP INDEX index_pa_aa_1;
-- DROP INDEX index_pa_handlers_1;
-- DROP INDEX idx_pa_trasf_resp_2;
-- DROP INDEX idx_pa_trasf_resp_1;
-- DROP INDEX index_pa_transform_sa_1;
-- DROP INDEX index_pa_transform_soggetti_1;
-- DROP INDEX index_pa_transform_2;
-- DROP INDEX index_pa_transform_1;
-- DROP INDEX index_pa_azioni_1;
-- DROP INDEX index_pa_soggetti_1;
-- DROP INDEX index_pa_scope_1;
-- DROP INDEX index_pa_ruoli_1;
-- DROP INDEX index_porte_applicative_1;
-- DROP INDEX INDEX_PA_TOKEN_SA;
-- DROP INDEX idx_pa_trasf_hdr_resp_1;
-- DROP INDEX idx_pa_trasf_url_1;
-- DROP INDEX idx_pa_trasf_hdr_1;
-- DROP INDEX INDEX_PA_CACHE;
-- DROP INDEX INDEX_PA_SA_AUTH;
-- DROP INDEX INDEX_PA_CORR_RES;
-- DROP INDEX INDEX_PA_CORR_REQ;
-- DROP INDEX INDEX_PA_WSSRES;
-- DROP INDEX INDEX_PA_WSSREQ;
-- DROP INDEX INDEX_PA_MTOMTRES;
-- DROP INDEX INDEX_PA_MTOMTREQ;
-- DROP INDEX INDEX_PA_PROP;
-- DROP INDEX INDEX_PA_CT_PROP;
-- DROP INDEX idx_pa_ct_props_1;
-- DROP INDEX INDEX_PA_AUTHZC_PROP;
-- DROP INDEX INDEX_PA_AUTHZ_PROP;
-- DROP INDEX INDEX_PA_AUTH_PROP;
-- DROP INDEX INDEX_PA_BEHAVIOUR_PROP;
-- DROP INDEX INDEX_PA_SA_PROP;
-- DROP INDEX INDEX_PA_SA_CODA_MAX;
-- DROP INDEX INDEX_PA_SA_CODA;
-- DROP INDEX INDEX_PA_SA;
-- DROP INDEX index_porte_applicative_3;
-- DROP INDEX index_porte_applicative_2;
DROP TABLE pa_token_ruoli_init_seq;
DROP TABLE pa_token_ruoli;
DROP TABLE pa_token_sa_init_seq;
DROP TABLE pa_token_sa;
DROP TABLE pa_aa_init_seq;
DROP TABLE pa_aa;
DROP TABLE pa_handlers_init_seq;
DROP TABLE pa_handlers;
DROP TABLE pa_transform_risp_hdr_init_seq;
DROP TABLE pa_transform_risp_hdr;
DROP TABLE pa_transform_risp_init_seq;
DROP TABLE pa_transform_risp;
DROP TABLE pa_transform_url_init_seq;
DROP TABLE pa_transform_url;
DROP TABLE pa_transform_hdr_init_seq;
DROP TABLE pa_transform_hdr;
DROP TABLE pa_transform_sa_init_seq;
DROP TABLE pa_transform_sa;
DROP TABLE pa_transform_soggetti_init_seq;
DROP TABLE pa_transform_soggetti;
DROP TABLE pa_transform_init_seq;
DROP TABLE pa_transform;
DROP TABLE pa_cache_regole_init_seq;
DROP TABLE pa_cache_regole;
DROP TABLE pa_azioni_init_seq;
DROP TABLE pa_azioni;
DROP TABLE porte_applicative_sa_auth_init_seq;
DROP TABLE porte_applicative_sa_auth;
DROP TABLE pa_soggetti_init_seq;
DROP TABLE pa_soggetti;
DROP TABLE pa_scope_init_seq;
DROP TABLE pa_scope;
DROP TABLE pa_ruoli_init_seq;
DROP TABLE pa_ruoli;
DROP TABLE pa_correlazione_risposta_init_seq;
DROP TABLE pa_correlazione_risposta;
DROP TABLE pa_correlazione_init_seq;
DROP TABLE pa_correlazione;
DROP TABLE pa_security_response_init_seq;
DROP TABLE pa_security_response;
DROP TABLE pa_security_request_init_seq;
DROP TABLE pa_security_request;
DROP TABLE pa_mtom_response_init_seq;
DROP TABLE pa_mtom_response;
DROP TABLE pa_mtom_request_init_seq;
DROP TABLE pa_mtom_request;
DROP TABLE pa_properties_init_seq;
DROP TABLE pa_properties;
DROP TABLE pa_ct_properties_init_seq;
DROP TABLE pa_ct_properties;
DROP TABLE pa_authzc_properties_init_seq;
DROP TABLE pa_authzc_properties;
DROP TABLE pa_authz_properties_init_seq;
DROP TABLE pa_authz_properties;
DROP TABLE pa_auth_properties_init_seq;
DROP TABLE pa_auth_properties;
DROP TABLE pa_behaviour_props_init_seq;
DROP TABLE pa_behaviour_props;
DROP TABLE pa_sa_properties_init_seq;
DROP TABLE pa_sa_properties;
DROP TABLE porte_applicative_sa_init_seq;
DROP TABLE porte_applicative_sa;
DROP TABLE porte_applicative_init_seq;
DROP TABLE porte_applicative;
DROP SEQUENCE seq_pa_token_ruoli;
DROP SEQUENCE seq_pa_token_sa;
DROP SEQUENCE seq_pa_aa;
DROP SEQUENCE seq_pa_handlers;
DROP SEQUENCE seq_pa_transform_risp_hdr;
DROP SEQUENCE seq_pa_transform_risp;
DROP SEQUENCE seq_pa_transform_url;
DROP SEQUENCE seq_pa_transform_hdr;
DROP SEQUENCE seq_pa_transform_sa;
DROP SEQUENCE seq_pa_transform_soggetti;
DROP SEQUENCE seq_pa_transform;
DROP SEQUENCE seq_pa_cache_regole;
DROP SEQUENCE seq_pa_azioni;
DROP SEQUENCE seq_porte_applicative_sa_auth;
DROP SEQUENCE seq_pa_soggetti;
DROP SEQUENCE seq_pa_scope;
DROP SEQUENCE seq_pa_ruoli;
DROP SEQUENCE seq_pa_correlazione_risposta;
DROP SEQUENCE seq_pa_correlazione;
DROP SEQUENCE seq_pa_security_response;
DROP SEQUENCE seq_pa_security_request;
DROP SEQUENCE seq_pa_mtom_response;
DROP SEQUENCE seq_pa_mtom_request;
DROP SEQUENCE seq_pa_properties;
DROP SEQUENCE seq_pa_ct_properties;
DROP SEQUENCE seq_pa_authzc_properties;
DROP SEQUENCE seq_pa_authz_properties;
DROP SEQUENCE seq_pa_auth_properties;
DROP SEQUENCE seq_pa_behaviour_props;
DROP SEQUENCE seq_pa_sa_properties;
DROP SEQUENCE seq_porte_applicative_sa;
DROP SEQUENCE seq_porte_applicative;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_pd_token_ruoli_1;
-- DROP INDEX index_pd_aa_1;
-- DROP INDEX index_pd_handlers_1;
-- DROP INDEX idx_pd_trasf_resp_2;
-- DROP INDEX idx_pd_trasf_resp_1;
-- DROP INDEX index_pd_transform_sa_1;
-- DROP INDEX index_pd_transform_2;
-- DROP INDEX index_pd_transform_1;
-- DROP INDEX index_pd_azioni_1;
-- DROP INDEX index_pd_scope_1;
-- DROP INDEX index_pd_ruoli_1;
-- DROP INDEX index_porte_delegate_1;
-- DROP INDEX INDEX_PD_TOKEN_SA;
-- DROP INDEX idx_pd_trasf_hdr_resp_1;
-- DROP INDEX idx_pd_trasf_url_1;
-- DROP INDEX idx_pd_trasf_hdr_1;
-- DROP INDEX INDEX_PD_CACHE;
-- DROP INDEX INDEX_PD_CORR_RES;
-- DROP INDEX INDEX_PD_CORR_REQ;
-- DROP INDEX INDEX_PD_WSSRES;
-- DROP INDEX INDEX_PD_WSSREQ;
-- DROP INDEX INDEX_PD_MTOMTRES;
-- DROP INDEX INDEX_PD_MTOMTREQ;
-- DROP INDEX INDEX_PD_PROP;
-- DROP INDEX INDEX_PD_CT_PROP;
-- DROP INDEX idx_pd_ct_props_1;
-- DROP INDEX INDEX_PD_AUTHZC_PROP;
-- DROP INDEX INDEX_PD_AUTHZ_PROP;
-- DROP INDEX INDEX_PD_AUTH_PROP;
-- DROP INDEX INDEX_PD_SA;
-- DROP INDEX index_porte_delegate_3;
-- DROP INDEX index_porte_delegate_2;
DROP TABLE pd_token_ruoli_init_seq;
DROP TABLE pd_token_ruoli;
DROP TABLE pd_token_sa_init_seq;
DROP TABLE pd_token_sa;
DROP TABLE pd_aa_init_seq;
DROP TABLE pd_aa;
DROP TABLE pd_handlers_init_seq;
DROP TABLE pd_handlers;
DROP TABLE pd_transform_risp_hdr_init_seq;
DROP TABLE pd_transform_risp_hdr;
DROP TABLE pd_transform_risp_init_seq;
DROP TABLE pd_transform_risp;
DROP TABLE pd_transform_url_init_seq;
DROP TABLE pd_transform_url;
DROP TABLE pd_transform_hdr_init_seq;
DROP TABLE pd_transform_hdr;
DROP TABLE pd_transform_sa_init_seq;
DROP TABLE pd_transform_sa;
DROP TABLE pd_transform_init_seq;
DROP TABLE pd_transform;
DROP TABLE pd_cache_regole_init_seq;
DROP TABLE pd_cache_regole;
DROP TABLE pd_azioni_init_seq;
DROP TABLE pd_azioni;
DROP TABLE pd_scope_init_seq;
DROP TABLE pd_scope;
DROP TABLE pd_ruoli_init_seq;
DROP TABLE pd_ruoli;
DROP TABLE pd_correlazione_risposta_init_seq;
DROP TABLE pd_correlazione_risposta;
DROP TABLE pd_correlazione_init_seq;
DROP TABLE pd_correlazione;
DROP TABLE pd_security_response_init_seq;
DROP TABLE pd_security_response;
DROP TABLE pd_security_request_init_seq;
DROP TABLE pd_security_request;
DROP TABLE pd_mtom_response_init_seq;
DROP TABLE pd_mtom_response;
DROP TABLE pd_mtom_request_init_seq;
DROP TABLE pd_mtom_request;
DROP TABLE pd_properties_init_seq;
DROP TABLE pd_properties;
DROP TABLE pd_ct_properties_init_seq;
DROP TABLE pd_ct_properties;
DROP TABLE pd_authzc_properties_init_seq;
DROP TABLE pd_authzc_properties;
DROP TABLE pd_authz_properties_init_seq;
DROP TABLE pd_authz_properties;
DROP TABLE pd_auth_properties_init_seq;
DROP TABLE pd_auth_properties;
DROP TABLE porte_delegate_sa_init_seq;
DROP TABLE porte_delegate_sa;
DROP TABLE porte_delegate_init_seq;
DROP TABLE porte_delegate;
DROP SEQUENCE seq_pd_token_ruoli;
DROP SEQUENCE seq_pd_token_sa;
DROP SEQUENCE seq_pd_aa;
DROP SEQUENCE seq_pd_handlers;
DROP SEQUENCE seq_pd_transform_risp_hdr;
DROP SEQUENCE seq_pd_transform_risp;
DROP SEQUENCE seq_pd_transform_url;
DROP SEQUENCE seq_pd_transform_hdr;
DROP SEQUENCE seq_pd_transform_sa;
DROP SEQUENCE seq_pd_transform;
DROP SEQUENCE seq_pd_cache_regole;
DROP SEQUENCE seq_pd_azioni;
DROP SEQUENCE seq_pd_scope;
DROP SEQUENCE seq_pd_ruoli;
DROP SEQUENCE seq_pd_correlazione_risposta;
DROP SEQUENCE seq_pd_correlazione;
DROP SEQUENCE seq_pd_security_response;
DROP SEQUENCE seq_pd_security_request;
DROP SEQUENCE seq_pd_mtom_response;
DROP SEQUENCE seq_pd_mtom_request;
DROP SEQUENCE seq_pd_properties;
DROP SEQUENCE seq_pd_ct_properties;
DROP SEQUENCE seq_pd_authzc_properties;
DROP SEQUENCE seq_pd_authz_properties;
DROP SEQUENCE seq_pd_auth_properties;
DROP SEQUENCE seq_porte_delegate_sa;
DROP SEQUENCE seq_porte_delegate;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_sa_ruoli_1;
-- DROP INDEX index_servizi_applicativi_1;
-- DROP INDEX INDEX_SA_PROP;
-- DROP INDEX INDEX_SA_CRED;
-- DROP INDEX INDEX_SA_RUOLI;
-- DROP INDEX index_servizi_applicativi_2;
DROP TABLE sa_properties_init_seq;
DROP TABLE sa_properties;
DROP TABLE sa_credenziali_init_seq;
DROP TABLE sa_credenziali;
DROP TABLE sa_ruoli_init_seq;
DROP TABLE sa_ruoli;
DROP TABLE servizi_applicativi_init_seq;
DROP TABLE servizi_applicativi;
DROP SEQUENCE seq_sa_properties;
DROP SEQUENCE seq_sa_credenziali;
DROP SEQUENCE seq_sa_ruoli;
DROP SEQUENCE seq_servizi_applicativi;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_trans_pers_risorse_1;
-- DROP INDEX idx_trans_pers_stati_1;
-- DROP INDEX idx_conf_trans_plug_2;
-- DROP INDEX idx_conf_trans_plug_1;
-- DROP INDEX idx_trans_pers_1;
DROP TABLE conf_risorse_contenuti_init_seq;
DROP TABLE conf_risorse_contenuti;
DROP TABLE configurazione_stati_init_seq;
DROP TABLE configurazione_stati;
DROP TABLE config_tran_plugins_init_seq;
DROP TABLE config_tran_plugins;
DROP TABLE config_transazioni_init_seq;
DROP TABLE config_transazioni;
DROP SEQUENCE seq_conf_risorse_contenuti;
DROP SEQUENCE seq_configurazione_stati;
DROP SEQUENCE seq_config_tran_plugins;
DROP SEQUENCE seq_config_transazioni;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_ricerche_pers_2;
-- DROP INDEX idx_ricerche_pers_1;
DROP TABLE ricerche_personalizzate_init_seq;
DROP TABLE ricerche_personalizzate;
DROP SEQUENCE seq_ricerche_personalizzate;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_stat_pers_2;
-- DROP INDEX idx_stat_pers_1;
DROP TABLE stat_personalizzate_init_seq;
DROP TABLE stat_personalizzate;
DROP SEQUENCE seq_stat_personalizzate;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_conf_filtri_1;
-- DROP INDEX index_plugins_conf_azioni_1;
-- DROP INDEX index_plugins_azioni_comp_1;
-- DROP INDEX index_plugins_3;
-- DROP INDEX index_plugins_2;
-- DROP INDEX index_plugins_1;
-- DROP INDEX idx_conf_servizi_1;
-- DROP INDEX idx_plug_prop_com_1;
-- DROP INDEX idx_plug_ser_com_1;
DROP TABLE plugins_conf_filtri_init_seq;
DROP TABLE plugins_conf_filtri;
DROP TABLE plugins_conf_azioni_init_seq;
DROP TABLE plugins_conf_azioni;
DROP TABLE plugins_conf_servizi_init_seq;
DROP TABLE plugins_conf_servizi;
DROP TABLE plugins_props_comp_init_seq;
DROP TABLE plugins_props_comp;
DROP TABLE plugins_azioni_comp_init_seq;
DROP TABLE plugins_azioni_comp;
DROP TABLE plugins_servizi_comp_init_seq;
DROP TABLE plugins_servizi_comp;
DROP TABLE plugins_init_seq;
DROP TABLE plugins;
DROP SEQUENCE seq_plugins_conf_filtri;
DROP SEQUENCE seq_plugins_conf_azioni;
DROP SEQUENCE seq_plugins_conf_servizi;
DROP SEQUENCE seq_plugins_props_comp;
DROP SEQUENCE seq_plugins_azioni_comp;
DROP SEQUENCE seq_plugins_servizi_comp;
DROP SEQUENCE seq_plugins;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_acc_serv_composti_1;
-- DROP INDEX index_serv_fru_azione_1;
-- DROP INDEX index_servizi_fruitori_1;
-- DROP INDEX index_servizi_azione_1;
-- DROP INDEX index_servizi_1;
-- DROP INDEX index_accordi_cooperazione_1;
-- DROP INDEX idx_acc_gruppi_1;
-- DROP INDEX index_api_resp_1;
-- DROP INDEX index_api_resources_2;
-- DROP INDEX index_api_resources_1;
-- DROP INDEX index_port_type_azioni_1;
-- DROP INDEX index_port_type_1;
-- DROP INDEX index_accordi_azioni_1;
-- DROP INDEX index_accordi_1;
-- DROP INDEX index_documenti_1;
-- DROP INDEX INDEX_AC_SC_SERV;
-- DROP INDEX INDEX_AC_SC_SC;
-- DROP INDEX INDEX_AC_SC;
-- DROP INDEX index_serv_fru_azioni_1;
-- DROP INDEX INDEX_SERV_FRU_SOG;
-- DROP INDEX index_servizi_azioni_1;
-- DROP INDEX INDEX_SERV_SOG;
-- DROP INDEX INDEX_SERV_ACC;
-- DROP INDEX INDEX_AC_SOG;
-- DROP INDEX INDEX_AC_COOP_PAR;
-- DROP INDEX INDEX_OP_MESSAGES;
-- DROP INDEX index_accordi_2;
-- DROP INDEX INDEX_DOC_SEARCH;
DROP TABLE acc_serv_componenti_init_seq;
DROP TABLE acc_serv_componenti;
DROP TABLE acc_serv_composti_init_seq;
DROP TABLE acc_serv_composti;
DROP TABLE servizi_fruitori_azione_init_seq;
DROP TABLE servizi_fruitori_azione;
DROP TABLE servizi_fruitori_azioni_init_seq;
DROP TABLE servizi_fruitori_azioni;
DROP TABLE servizi_fruitori_init_seq;
DROP TABLE servizi_fruitori;
DROP TABLE servizi_azione_init_seq;
DROP TABLE servizi_azione;
DROP TABLE servizi_azioni_init_seq;
DROP TABLE servizi_azioni;
DROP TABLE servizi_init_seq;
DROP TABLE servizi;
DROP TABLE accordi_coop_partecipanti_init_seq;
DROP TABLE accordi_coop_partecipanti;
DROP TABLE accordi_cooperazione_init_seq;
DROP TABLE accordi_cooperazione;
DROP TABLE accordi_gruppi_init_seq;
DROP TABLE accordi_gruppi;
DROP TABLE api_resources_parameter_init_seq;
DROP TABLE api_resources_parameter;
DROP TABLE api_resources_media_init_seq;
DROP TABLE api_resources_media;
DROP TABLE api_resources_response_init_seq;
DROP TABLE api_resources_response;
DROP TABLE api_resources_init_seq;
DROP TABLE api_resources;
DROP TABLE operation_messages_init_seq;
DROP TABLE operation_messages;
DROP TABLE port_type_azioni_init_seq;
DROP TABLE port_type_azioni;
DROP TABLE port_type_init_seq;
DROP TABLE port_type;
DROP TABLE accordi_azioni_init_seq;
DROP TABLE accordi_azioni;
DROP TABLE accordi_init_seq;
DROP TABLE accordi;
DROP TABLE documenti_init_seq;
DROP TABLE documenti;
DROP SEQUENCE seq_acc_serv_componenti;
DROP SEQUENCE seq_acc_serv_composti;
DROP SEQUENCE seq_servizi_fruitori_azione;
DROP SEQUENCE seq_servizi_fruitori_azioni;
DROP SEQUENCE seq_servizi_fruitori;
DROP SEQUENCE seq_servizi_azione;
DROP SEQUENCE seq_servizi_azioni;
DROP SEQUENCE seq_servizi;
DROP SEQUENCE seq_accordi_coop_partecipanti;
DROP SEQUENCE seq_accordi_cooperazione;
DROP SEQUENCE seq_accordi_gruppi;
DROP SEQUENCE seq_api_resources_parameter;
DROP SEQUENCE seq_api_resources_media;
DROP SEQUENCE seq_api_resources_response;
DROP SEQUENCE seq_api_resources;
DROP SEQUENCE seq_operation_messages;
DROP SEQUENCE seq_port_type_azioni;
DROP SEQUENCE seq_port_type;
DROP SEQUENCE seq_accordi_azioni;
DROP SEQUENCE seq_accordi;
DROP SEQUENCE seq_documenti;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_soggetti_ruoli_1;
-- DROP INDEX index_soggetti_2;
-- DROP INDEX index_soggetti_1;
-- DROP INDEX INDEX_SOGGETTI_PROP;
-- DROP INDEX INDEX_SOGGETTI_CRED;
-- DROP INDEX INDEX_SOGGETTI_RUOLI;
DROP TABLE soggetti_properties_init_seq;
DROP TABLE soggetti_properties;
DROP TABLE soggetti_credenziali_init_seq;
DROP TABLE soggetti_credenziali;
DROP TABLE soggetti_ruoli_init_seq;
DROP TABLE soggetti_ruoli;
DROP TABLE soggetti_init_seq;
DROP TABLE soggetti;
DROP SEQUENCE seq_soggetti_properties;
DROP SEQUENCE seq_soggetti_credenziali;
DROP SEQUENCE seq_soggetti_ruoli;
DROP SEQUENCE seq_soggetti;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_scope_1;
DROP TABLE scope_init_seq;
DROP TABLE scope;
DROP SEQUENCE seq_scope;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_ruoli_1;
DROP TABLE ruoli_init_seq;
DROP TABLE ruoli;
DROP SEQUENCE seq_ruoli;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_gruppi_1;
DROP TABLE gruppi_init_seq;
DROP TABLE gruppi;
DROP SEQUENCE seq_gruppi;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_protocol_properties_1;
DROP TABLE protocol_properties_init_seq;
DROP TABLE protocol_properties;
DROP SEQUENCE seq_protocol_properties;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_connettori_properties_1;
-- DROP INDEX index_connettori_1;
-- DROP INDEX idx_conn_custom_1;
DROP TABLE connettori_properties_init_seq;
DROP TABLE connettori_properties;
DROP TABLE connettori_custom_init_seq;
DROP TABLE connettori_custom;
DROP TABLE connettori_init_seq;
DROP TABLE connettori;
DROP SEQUENCE seq_connettori_properties;
DROP SEQUENCE seq_connettori_custom;
DROP SEQUENCE seq_connettori;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_gest_err_soap_1;
-- DROP INDEX idx_gest_err_trasporto_1;
DROP TABLE gestione_errore_soap_init_seq;
DROP TABLE gestione_errore_soap;
DROP TABLE gestione_errore_trasporto_init_seq;
DROP TABLE gestione_errore_trasporto;
DROP TABLE gestione_errore_init_seq;
DROP TABLE gestione_errore;
DROP SEQUENCE seq_gestione_errore_soap;
DROP SEQUENCE seq_gestione_errore_trasporto;
DROP SEQUENCE seq_gestione_errore;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_pdd_1;
DROP TABLE pdd_init_seq;
DROP TABLE pdd;
DROP SEQUENCE seq_pdd;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TABLE db_info_console_init_seq_console;
DROP TABLE db_info_console;
DROP SEQUENCE seq_db_info_console;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_remote_store_key_1;
-- DROP INDEX index_remote_store_1;
-- DROP INDEX index_nodi_runtime_2;
-- DROP INDEX index_nodi_runtime_1;
-- DROP INDEX index_config_handlers_1;
-- DROP INDEX index_registro_plugins_1;
-- DROP INDEX index_generic_properties_1;
-- DROP INDEX index_pdd_sys_props_1;
-- DROP INDEX index_servizi_pdd_1;
-- DROP INDEX index_config_url_regole_1;
-- DROP INDEX INDEX_REF_SERVIZI;
-- DROP INDEX REMOTE_STORE_CREATE;
-- DROP INDEX REMOTE_STORE_UPDATE;
-- DROP INDEX INDEX_NODI_OP;
-- DROP INDEX index_registro_plug_jar_1;
-- DROP INDEX index_generic_property_1;
-- DROP INDEX index_dump_config_1;
-- DROP INDEX index_filetrace_config_1;
-- DROP INDEX index_tracce_config_1;
DROP TABLE servizi_digest_params_init_seq;
DROP TABLE servizi_digest_params;
DROP TABLE remote_store_key_init_seq;
DROP TABLE remote_store_key;
DROP TABLE remote_store_init_seq;
DROP TABLE remote_store;
DROP TABLE nodi_runtime_operations_init_seq;
DROP TABLE nodi_runtime_operations;
DROP TABLE nodi_runtime_init_seq;
DROP TABLE nodi_runtime;
DROP TABLE config_handlers_init_seq;
DROP TABLE config_handlers;
DROP TABLE registro_plug_jar_init_seq;
DROP TABLE registro_plug_jar;
DROP TABLE registro_plugins_init_seq;
DROP TABLE registro_plugins;
DROP TABLE canali_nodi_init_seq;
DROP TABLE canali_nodi;
DROP TABLE canali_configurazione_init_seq;
DROP TABLE canali_configurazione;
DROP TABLE generic_property_init_seq;
DROP TABLE generic_property;
DROP TABLE generic_properties_init_seq;
DROP TABLE generic_properties;
DROP TABLE pdd_sys_props_init_seq;
DROP TABLE pdd_sys_props;
DROP TABLE servizi_pdd_filtri_init_seq;
DROP TABLE servizi_pdd_filtri;
DROP TABLE servizi_pdd_init_seq;
DROP TABLE servizi_pdd;
DROP TABLE tracce_ds_prop_init_seq;
DROP TABLE tracce_ds_prop;
DROP TABLE tracce_ds_init_seq;
DROP TABLE tracce_ds;
DROP TABLE msgdiag_ds_prop_init_seq;
DROP TABLE msgdiag_ds_prop;
DROP TABLE msgdiag_ds_init_seq;
DROP TABLE msgdiag_ds;
DROP TABLE dump_appender_prop_init_seq;
DROP TABLE dump_appender_prop;
DROP TABLE dump_appender_init_seq;
DROP TABLE dump_appender;
DROP TABLE dump_config_regola_init_seq;
DROP TABLE dump_config_regola;
DROP TABLE dump_config_init_seq;
DROP TABLE dump_config;
DROP TABLE filetrace_config_init_seq;
DROP TABLE filetrace_config;
DROP TABLE tracce_config_init_seq;
DROP TABLE tracce_config;
DROP TABLE tracce_appender_prop_init_seq;
DROP TABLE tracce_appender_prop;
DROP TABLE tracce_appender_init_seq;
DROP TABLE tracce_appender;
DROP TABLE msgdiag_appender_prop_init_seq;
DROP TABLE msgdiag_appender_prop;
DROP TABLE msgdiag_appender_init_seq;
DROP TABLE msgdiag_appender;
DROP TABLE config_url_regole_init_seq;
DROP TABLE config_url_regole;
DROP TABLE config_url_invocazione_init_seq;
DROP TABLE config_url_invocazione;
DROP TABLE configurazione_init_seq;
DROP TABLE configurazione;
DROP TABLE config_cache_regole_init_seq;
DROP TABLE config_cache_regole;
DROP TABLE routing_init_seq;
DROP TABLE routing;
DROP TABLE registri_init_seq;
DROP TABLE registri;
DROP SEQUENCE seq_servizi_digest_params;
DROP SEQUENCE seq_remote_store_key;
DROP SEQUENCE seq_remote_store;
DROP SEQUENCE seq_nodi_runtime_operations;
DROP SEQUENCE seq_nodi_runtime;
DROP SEQUENCE seq_config_handlers;
DROP SEQUENCE seq_registro_plug_jar;
DROP SEQUENCE seq_registro_plugins;
DROP SEQUENCE seq_canali_nodi;
DROP SEQUENCE seq_canali_configurazione;
DROP SEQUENCE seq_generic_property;
DROP SEQUENCE seq_generic_properties;
DROP SEQUENCE seq_pdd_sys_props;
DROP SEQUENCE seq_servizi_pdd_filtri;
DROP SEQUENCE seq_servizi_pdd;
DROP SEQUENCE seq_tracce_ds_prop;
DROP SEQUENCE seq_tracce_ds;
DROP SEQUENCE seq_msgdiag_ds_prop;
DROP SEQUENCE seq_msgdiag_ds;
DROP SEQUENCE seq_dump_appender_prop;
DROP SEQUENCE seq_dump_appender;
DROP SEQUENCE seq_dump_config_regola;
DROP SEQUENCE seq_dump_config;
DROP SEQUENCE seq_filetrace_config;
DROP SEQUENCE seq_tracce_config;
DROP SEQUENCE seq_tracce_appender_prop;
DROP SEQUENCE seq_tracce_appender;
DROP SEQUENCE seq_msgdiag_appender_prop;
DROP SEQUENCE seq_msgdiag_appender;
DROP SEQUENCE seq_config_url_regole;
DROP SEQUENCE seq_config_url_invocazione;
DROP SEQUENCE seq_configurazione;
DROP SEQUENCE seq_config_cache_regole;
DROP SEQUENCE seq_routing;
DROP SEQUENCE seq_registri;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_cong_att_policy_1;
-- DROP INDEX idx_cong_gen_policy_1;
-- DROP INDEX idx_rt_prop_policy_1;
-- DROP INDEX idx_cong_att_policy_2;
-- DROP INDEX idx_rt_prop_policy_2;
DROP TABLE ct_active_policy_init_seq;
DROP TABLE ct_active_policy;
DROP TABLE ct_config_policy_init_seq;
DROP TABLE ct_config_policy;
DROP TABLE ct_rt_props_init_seq;
DROP TABLE ct_rt_props;
DROP TABLE ct_config_init_seq;
DROP TABLE ct_config;
DROP SEQUENCE seq_ct_active_policy;
DROP SEQUENCE seq_ct_config_policy;
DROP SEQUENCE seq_ct_rt_props;
DROP SEQUENCE seq_ct_config;


-- govway
		  		
